#!/bin/bash
#
# Generic cron script to maintain a given udptap set up
#
# The configuration defines:
# TAP = the tap device to use
# IP = the local IP for the tap (optional)
# BR = bridge to add the tap to (optional)
# PORT = the local UDP port to service (all interfaces)
# VPN = the udptap remotes list
# IGN = the udptap ignored macs list
# VERBOSE= empty, -v, -vv, or -vvv (optional; empty for non-verbose)

die() { echo "$*" >&1 ; exit 1 ; }

UDPTAP=/usr/local/sbin/udptap
FLOCK=/usr/bin/flock
TAPUSER=root
LOCK="/var/lock/udptap-$TAP"

. /etc/udptap/conf.d/$1.conf || die Missing configuration for $1
[ -z "$TAP" ] && die unknown TAP
[ -z "$PORT" ] && die unknown PORT
[ -z "$VPN" ] && die unknown VPN
V="${VERBOSE#-v}"
[ -z "${V#v}" ] || [ -z "${V#vv}" ] || \
    die VERBOSE must be empty, -v, -vv, or -vvv

# Spawn the updtap server, with flock on $LOCK
{
    $FLOCK -n 9 || exit 0
    /sbin/ip tuntap add "$TAP" mode tap user $TAPUSER >&2
    /sbin/ifconfig "$TAP" "$IP" up >&2
    [ -z "$BR" ] || /sbin/brctl addif "$BR" "$TAP"
    if [ -n "$IGN" ] ; then
	IGN="${IGN[*]}"
	IGN=( -i ${IGN// /,} )
    fi
    echo $UDPTAP $VERBOSE "${IGN[@]}" -t "$TAP" "$PORT" "${VPN[@]}" >&2
    exec $UDPTAP $VERBOSE "${IGN[@]}" -t "$TAP" "$PORT" "${VPN[@]}"
} 9> "$LOCK" &
